==> mono-1.1.7.tar.gz: mono-1.1.7/mcs/class/corlib/System.Runtime.ConstrainedExecution/CriticialFinalizerObject.cs <==
//
// System.Runtime.ConstrainedExecution.CriticalFinalizerObject class
//
// Author:
//    Duncan Mak (duncan@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//

#if NET_2_0
namespace System.Runtime.ConstrainedExecution
{
        public abstract class CriticalFinalizerObject
        {
                protected CriticalFinalizerObject ()
                {
                }

		[ReliabilityContract (Consistency.WillNotCorruptState, CER.Success)]
		~CriticalFinalizerObject ()
		{
		}
        }
}
#endif

==> mono-1.1.9.2.tar.gz: mono-1.1.9.2/mcs/class/corlib/System.Runtime.ConstrainedExecution/CriticialFinalizerObject.cs <==
//
// System.Runtime.ConstrainedExecution.CriticalFinalizerObject class
//
// Author:
//    Duncan Mak (duncan@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//

#if NET_2_0

using System.Runtime.InteropServices;

namespace System.Runtime.ConstrainedExecution
{
	[ComVisible (true)]
        public abstract class CriticalFinalizerObject
        {
                protected CriticalFinalizerObject ()
                {
                }

		[ReliabilityContract (Consistency.WillNotCorruptState, Cer.Success)]
		~CriticalFinalizerObject ()
		{
		}
        }
}
#endif
